pub fn text_context_lines(cut_result: &CutResult) -> Vec<SourceContextLine>Expand description
Convert a CutResult into context lines with plain text content (no highlighting).
pub fn text_context_lines(cut_result: &CutResult) -> Vec<SourceContextLine>Convert a CutResult into context lines with plain text content (no highlighting).